Getting started
===============

1. Install Harbor

.. code:: bash

    pip install rkd-harbor

2. Create GIT project

.. code:: bash

    mkdir my-project
    cd my-project

    git init

3. Create Harbor project

.. code:: bash

    harbor :create:project


Read about project :ref:`structure`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
